summaryrefslogtreecommitdiff
path: root/include
diff options
context:
space:
mode:
authorNoel Grandin <noel.grandin@collabora.co.uk>2024-05-10 11:39:18 +0200
committerNoel Grandin <noel.grandin@collabora.co.uk>2024-05-13 14:44:19 +0200
commit57dc0cbd8ebfe465f9e21a47c253a8437f8860a9 (patch)
tree3c545bb0702f5177b642af9df8ee69ea0acf62c5 /include
parentb6652dae45a469bc0e357ff4755a92992b0856e9 (diff)
do less OString->OUString conversion in tools datetime functions
Change-Id: I93d012f32b8006019c431b8bf88ab9c7ffb4d3a0 Reviewed-on: https://gerrit.libreoffice.org/c/core/+/167574 Reviewed-by: Noel Grandin <noel.grandin@collabora.co.uk> Tested-by: Jenkins
Diffstat (limited to 'include')
-rw-r--r--include/tools/datetimeutils.hxx6
1 files changed, 4 insertions, 2 deletions
diff --git a/include/tools/datetimeutils.hxx b/include/tools/datetimeutils.hxx
index 3df6229cb574..deb7d7ee4f4c 100644
--- a/include/tools/datetimeutils.hxx
+++ b/include/tools/datetimeutils.hxx
@@ -14,12 +14,14 @@
// This function converts a 'DateTime' object to an 'OString' object
TOOLS_DLLPUBLIC OString DateTimeToOString(const DateTime& rDateTime);
+// This function converts a 'DateTime' object to an 'OUString' object
+TOOLS_DLLPUBLIC OUString DateTimeToOUString(const DateTime& rDateTime);
// This function converts a 'Date' object to an 'OString' object in ISO-8601 representation
TOOLS_DLLPUBLIC OString DateToOString(const Date& rDate);
-// This function converts a 'Date' object to an 'OString' object in DD/MM/YYYY format
-TOOLS_DLLPUBLIC OString DateToDDMMYYYYOString(const Date& rDate);
+// This function converts a 'Date' object to an 'OUString' object in DD/MM/YYYY format
+TOOLS_DLLPUBLIC OUString DateToDDMMYYYYOUString(const Date& rDate);
#endif